package com.example.android.gesture;

import java.util.ArrayList;
import java.util.Set;

import android.app.Activity;
import android.gesture.Gesture;
import android.gesture.GestureLibraries;
import android.gesture.GestureLibrary;
import android.gesture.GestureOverlayView;
import android.gesture.Prediction;
import android.gesture.GestureOverlayView.OnGestureListener;
import android.gesture.GestureOverlayView.OnGesturePerformedListener;
import android.gesture.GestureOverlayView.OnGesturingListener;
import android.os.Bundle;
import android.util.Log;
import android.view.MotionEvent;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.Toast;

public class Main extends Activity {
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		final GestureLibrary gl = GestureLibraries.fromPrivateFile(this, "gestures");
		Set<String> entries = gl.getGestureEntries();
		Log.v("Gesture", "entries.size:" + entries.size());
		for (String entry : entries) {
			Log.v("Gesture", "entry:" + entry);
		}
		
		setContentView(R.layout.main);
		GestureOverlayView gov = (GestureOverlayView)findViewById(R.id.GestureOverlayView01);
		
		CharSequence[] list = new CharSequence[20];
		for (int i = 0; i < list.length; i++) {
			list[i] = "item" + i;
		}
		
		ArrayAdapter<CharSequence> adapter = new ArrayAdapter<CharSequence>(this, android.R.layout.simple_list_item_1, list);
		ListView listView = (ListView)findViewById(R.id.ListView01);
		listView.setAdapter(adapter);
		
		gov.addOnGestureListener(new OnGestureListener() {
			
			@Override
			public void onGestureStarted(GestureOverlayView overlay, MotionEvent event) {
				Log.v("Gesture", "onGestureStarted");
			}
			
			@Override
			public void onGestureEnded(GestureOverlayView overlay, MotionEvent event) {
				Log.v("Gesture", "onGestureEnded");
			}
			
			@Override
			public void onGestureCancelled(GestureOverlayView overlay, MotionEvent event) {
				Log.v("Gesture", "onGestureCancelled");
			}
			
			@Override
			public void onGesture(GestureOverlayView overlay, MotionEvent event) {
				Log.v("Gesture", "onGesture");
			}
		});
		
		gov.addOnGesturePerformedListener(new OnGesturePerformedListener() {

			@Override
			public void onGesturePerformed(GestureOverlayView overlay, Gesture gesture) {
				Log.v("Gesture", "onGesturePerformed");
				Log.v("Gesture", "\tid:" + gesture.getID());
				Log.v("Gesture", "\tlength:" + gesture.getLength());
				Log.v("Gesture", "\tdescribeContents:" + gesture.describeContents());
				
				if (gl.getGestureEntries().size() == 0) {
					gl.addGesture("First", gesture);
					gl.save();
				} else {
					ArrayList<Prediction> predictions = gl.recognize(gesture);
					Log.v("Gesture", "\tpredictions.size:" + predictions.size());
					for (Prediction p : predictions) {
						Log.v("Gesture", "\tPrediction name:" + p.name + " score:" + p.score);
						Toast.makeText(Main.this, "score:" + p.score, Toast.LENGTH_SHORT).show();
					}
				}
			}
			
		});
		
		gov.addOnGesturingListener(new OnGesturingListener() {

			@Override
			public void onGesturingEnded(GestureOverlayView overlay) {
				Log.v("Gesture", "onGesturingEnded");
			}

			@Override
			public void onGesturingStarted(GestureOverlayView overlay) {
				Log.v("Gesture", "onGesturingStarted");
			}
			
		});
	}
}